@@ -1,5 +1,4 @@
 /**
-
  The purpose of this file is to provide the C-level facilities
  to create, modify and manage internal XML DOM nodes at the S
  language level. We want to be able to use the interface defined
@@ -370,7 +369,7 @@ RS_XML_getNsList(USER_OBJECT_ s_node, USER_OBJECT_ asRef)
 	PROTECT(names = NEW_CHARACTER(n));    
 	for(i = 0; i < n ; i++, el = el->next) {
 	    if(el->prefix)
-		SET_STRING_ELT(names, i, COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(el->prefix)));
+		SET_STRING_ELT(names, i, ENC_COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(el->prefix)));
 	    SET_VECTOR_ELT(ans, i, R_createXMLNsRef(el));
 	}
     } else {
@@ -379,9 +378,9 @@ RS_XML_getNsList(USER_OBJECT_ s_node, USER_OBJECT_ asRef)
 	PROTECT(names = NEW_CHARACTER(n));    
 	for(i = 0; i < n ; i++, el = el->next) {
 	    if(el->prefix)
-		SET_STRING_ELT(names, i, COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(el->prefix)));
+		SET_STRING_ELT(names, i, ENC_COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(el->prefix)));
 	    if(el->href)
-   	        SET_STRING_ELT(ans, i, COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(el->href)));
+   	        SET_STRING_ELT(ans, i, ENC_COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(el->href)));
 	}
     }
 
@@ -1217,7 +1216,7 @@ R_saveXMLDOM(USER_OBJECT_ sdoc, USER_OBJECT_ sfileName, USER_OBJECT_ compression
 
 	if(mem) {
 	    DECL_ENCODING_FROM_DOC(doc)
-	    SET_STRING_ELT(ans, 0, COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(mem))); 
+	    SET_STRING_ELT(ans, 0, ENC_COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(mem))); 
 	    xmlFree(mem);
 	} else { 
                /*XXX get the error message from libxml2 */
@@ -1468,11 +1467,11 @@ R_xmlNodeValue(SEXP node, SEXP raw, SEXP r_encoding)
    }
 */
    if(tmp) {
-#if 0
-     ans = ScalarString(CreateCharSexpWithEncoding(encoding, tmp));
-#else
-     ans = ScalarString(mkCharCE(tmp, INTEGER(r_encoding)[0]));
-#endif
+     if(INTEGER(r_encoding)[0] == CE_NATIVE)
+        ans = ScalarString(CreateCharSexpWithEncoding(encoding, tmp));
+     else
+        ans = ScalarString(mkCharCE(tmp, INTEGER(r_encoding)[0]));
+
 
      free(tmp);
 //     ans = mkString(XMLCHAR_TO_CHAR(tmp));
@@ -1501,9 +1500,9 @@ R_xmlNsAsCharacter(USER_OBJECT_ s_ns)
   SET_STRING_ELT(names, 1, mkChar("href"));
 
   if(ns->prefix)
-      SET_STRING_ELT(ans, 0, COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(ns->prefix)));
+      SET_STRING_ELT(ans, 0, ENC_COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(ns->prefix)));
   if(ns->href)
-      SET_STRING_ELT(ans, 1, COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(ns->href)));
+      SET_STRING_ELT(ans, 1, ENC_COPY_TO_USER_STRING(XMLCHAR_TO_CHAR(ns->href)));
 
   SET_NAMES(ans, names);
   UNPROTECT(2);
